/*
 * Kosmos.
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package hu.midori.kosmos.server.util;

import java.net.MalformedURLException;
import java.net.URL;

import org.apache.commons.lang.StringUtils;

/**
 * Utility methods for manipulating complicated URLs.
 *
 * @author <a href="mailto:aron.gombas@midori.hu">Aron Gombas</a>
 * @version $Id$
 */
public class UrlUtils {
    /** Returns the "base" part (the part that doesn't contain the path and query parts) of the given URL. */
    public static String getBaseUrl(String url) throws MalformedURLException {
        return url.substring(0, url.indexOf(new URL(url).getPath()));
    }
    
    /** Returns the "base" part and the "context path" part of the given URL. */
    public static String getContextUrl(String url) {
    	int index = StringUtils.indexOf(url, "//");
    	index = StringUtils.indexOf(url, "/", index + 2);
    	index = StringUtils.indexOf(url, "/", index + 1);

    	return StringUtils.substring(url, 0, index);    	
    }

    /**
     * Removes the userinfo part from the given URL.
     * @return the truncated URL.
     */
    public static String removeUserInfoFromUrl(String url) throws MalformedURLException {
        URL originalUrl = new URL(url);

        // remove the userinfo part and the separator '@'
        return StringUtils.remove(StringUtils.remove(originalUrl.toString(), originalUrl.getUserInfo()), '@');
    }

    /** Returns a two-element array with the username and password from the given URL, or <code>null</code> if those are not specified in the URL. */
    public static String[] parseUserInfoFromUrl(String url) throws MalformedURLException {
        String userInfo = new URL(url).getUserInfo();
        if(StringUtils.isBlank(userInfo))
            return null;

        String strings[] = StringUtils.split(userInfo, ':');
        if(strings.length != 2)
            throw new IllegalArgumentException(String.format("Invalid user info \"%s\"", userInfo));
        String userName = strings[0];
        String password = strings[1];
        if(StringUtils.isBlank(userName) || StringUtils.isBlank(password))
            throw new IllegalArgumentException(String.format("Invalid username (\"%s\") or password (\"%s\")", userName, password));

        return strings;
    }

    /** 
     * Kosmos uses an extended URL format. It is a standard URL
     * postfixed by a <code>:myvalue</code> string.
     * This method returns this extension.
     */
    public static String parseExtensionItemFromUrl(String url) {
        String additionalItem = StringUtils.substringAfterLast(url, ":");
        if(StringUtils.isBlank(additionalItem) || StringUtils.contains(additionalItem, '@'))
            throw new IllegalArgumentException(String.format("Invalid additional item (\"%s\") in \"%s\"", additionalItem, url));

        return additionalItem;
    }
}
